==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerListBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VerticalPodAutoscalerListBuilder extends VerticalPodAutoscalerListFluentImpl<VerticalPodAutoscalerListBuilder> implements VisitableBuilder<VerticalPodAutoscalerList,VerticalPodAutoscalerListBuilder>{
  public VerticalPodAutoscalerListBuilder() {
    this(false);
  }
  public VerticalPodAutoscalerListBuilder(Boolean validationEnabled) {
    this(new VerticalPodAutoscalerList(), validationEnabled);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent) {
    this(fluent, false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VerticalPodAutoscalerList(), validationEnabled);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,VerticalPodAutoscalerList instance) {
    this(fluent, instance, false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,VerticalPodAutoscalerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerList instance) {
    this(instance,false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  VerticalPodAutoscalerListFluent<?> fluent;
  Boolean validationEnabled;
  public VerticalPodAutoscalerList build() {
    VerticalPodAutoscalerList buildable = new VerticalPodAutoscalerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> verticalpodautoscaler-model-v1-6.8.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerListBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VerticalPodAutoscalerListBuilder extends VerticalPodAutoscalerListFluent<VerticalPodAutoscalerListBuilder> implements VisitableBuilder<VerticalPodAutoscalerList,VerticalPodAutoscalerListBuilder>{
  public VerticalPodAutoscalerListBuilder() {
    this(false);
  }
  public VerticalPodAutoscalerListBuilder(Boolean validationEnabled) {
    this(new VerticalPodAutoscalerList(), validationEnabled);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent) {
    this(fluent, false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VerticalPodAutoscalerList(), validationEnabled);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,VerticalPodAutoscalerList instance) {
    this(fluent, instance, false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerListFluent<?> fluent,VerticalPodAutoscalerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VerticalPodAutoscalerList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerList instance) {
    this(instance,false);
  }
  public VerticalPodAutoscalerListBuilder(VerticalPodAutoscalerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VerticalPodAutoscalerList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  VerticalPodAutoscalerListFluent<?> fluent;
  Boolean validationEnabled;
  public VerticalPodAutoscalerList build() {
    VerticalPodAutoscalerList buildable = new VerticalPodAutoscalerList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
